@@ -3,9 +3,8 @@ package CPANPLUS::Dist::Deb;
 use strict;
 use vars    qw[@ISA $VERSION];
 @ISA =      qw[CPANPLUS::Dist];
-$VERSION =  '0.10';
+$VERSION =  '0.12';
 
-use CPANPLUS::inc;
 use CPANPLUS::Error;
 use CPANPLUS::Internals::Constants;
 use CPANPLUS::Dist::Deb::Constants;
@@ -66,10 +65,9 @@ CPANPLUS::Dist::Deb
 
     ### from the CPANPLUS Default shell
     CPAN Terminal> i --format=CPANPLUS::Dist::Deb Some::Module
-
     
     ### using the commandline tool
-    cpan2dist -f CPANPLUS::Dist::Deb Some::Module
+    cpan2dist --format CPANPLUS::Dist::Deb Some::Module
     
 =head1 DESCRIPTION
 
